@@ -34,3 +34,15 @@ NEXT_ACTION_NAME = getattr(settings, 'BACKWARD_NEXT_ACTION_NAME', 'next_action')
 DEFAULT_REDIRECT_URL = getattr(settings,
                                'BACKWARD_DEFAULT_REDIRECT_URL',
                                '/')
+
+LOGIN_URL = getattr(settings,
+                    'BACKWARD_LOGIN_URL',
+                    settings.LOGIN_URL)
+
+IGNORE_AJAX = getattr(settings,
+                      'BACKWARD_IGNORE_AJAX',
+                      True)
+
+LOGIN_REDIRECT_URL = getattr(settings,
+                             'BACKWARD_LOGIN_REDIRECT_URL',
+                             settings.LOGIN_REDIRECT_URL)
